@@ -14,7 +14,7 @@ import robot
 from dgspoc.utils import File
 from dgspoc.utils import Misc
 
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 version = __version__
 
 __all__ = [
@@ -120,7 +120,7 @@ class Data:
             existed = 'Yes'
             with open(fn) as stream:
                 node = yaml.safe_load(stream)
-                total = len(node) if Misc.is_dict_instance(node) else 0
+                total = len(node) if Misc.is_dict(node) else 0
         else:
             existed = 'No'
             total = 0
